pub struct ColorizationResult {
pub cloud: PointCloud<ColoredPoint3f>,
pub colored_count: usize,
pub uncolored_count: usize,
}Expand description
Summary statistics returned by colorize_point_cloud.
Fields
cloud: PointCloud<ColoredPoint3f>Colored point cloud.
colored_count: usizeNumber of points that were successfully colored from an image.
uncolored_count: usizeNumber of points that received the default color (no image coverage).