pub fn segment_ground(
cloud: &PointCloud<Point3f>,
sensor_height: f32,
) -> Result<GroundSegmentationResult>Expand description
Convenience wrapper using default configuration with a given sensor height.
pub fn segment_ground(
cloud: &PointCloud<Point3f>,
sensor_height: f32,
) -> Result<GroundSegmentationResult>Convenience wrapper using default configuration with a given sensor height.