pub fn mesh_difference(
a: &TriangleMesh,
b: &TriangleMesh,
) -> Result<TriangleMesh>Expand description
Compute the boolean difference of two closed triangle meshes (A minus B).
Returns a mesh containing only the regions inside a but not b.
A.difference(B)
+-------+ +-------+
| | | |
| A | | A |
| +--+----+ = | +--+
+----+--+ | +----+
| B |
| |
+-------+