mesh_union

Function mesh_union 

pub fn mesh_union(a: &TriangleMesh, b: &TriangleMesh) -> Result<TriangleMesh>
Compute the boolean union of two closed triangle meshes.

Returns a mesh containing all regions inside either a or b.

    A.union(B)

    +-------+            +-------+
    |       |            |       |
    |   A   |            |       |
    |    +--+----+   =   |       +----+
    +----+--+    |       +----+       |
         |   B   |            |       |
         |       |            |       |
         +-------+            +-------+