Segmentation algorithms
Structs
- Cluster
Extraction Result - Result of Euclidean cluster extraction
- Euclidean
Cluster Config - Configuration for Euclidean cluster extraction
- Plane
Model - A 3D plane model defined by the equation ax + by + cz + d = 0
- Plane
Segmentation Result - RANSAC plane segmentation result
Functions
- extract_
euclidean_ clusters - Euclidean cluster extraction using a region-growing BFS approach.
- extract_
euclidean_ clusters_ parallel - Parallel Euclidean cluster extraction.
- plane_
segmentation_ ransac - RANSAC plane segmentation (alias for segment_plane_ransac)
- segment_
plane - Plane segmentation using RANSAC algorithm
- segment_
plane_ legacy Deprecated - Legacy function for backward compatibility
- segment_
plane_ parallel - Parallel RANSAC plane segmentation for better performance on large point clouds
- segment_
plane_ ransac - RANSAC plane segmentation with simplified interface