pub struct ClusterExtractionResult {
pub clusters: Vec<Vec<usize>>,
}Expand description
Result of Euclidean cluster extraction
Fields
clusters: Vec<Vec<usize>>Each inner Vec contains the point indices belonging to one cluster, ordered from largest to smallest cluster.
Implementations
Sourceimpl ClusterExtractionResult
impl ClusterExtractionResult
Sourcepub fn num_clusters(&self) -> usize
pub fn num_clusters(&self) -> usize
Number of clusters found
Sourcepub fn get_cluster_cloud(
&self,
cloud: &PointCloud<Point3f>,
index: usize,
) -> Option<PointCloud<Point3f>>
pub fn get_cluster_cloud( &self, cloud: &PointCloud<Point3f>, index: usize, ) -> Option<PointCloud<Point3f>>
Extract a sub-cloud for the cluster at index