pub fn mesh_intersection(
a: &TriangleMesh,
b: &TriangleMesh,
) -> Result<TriangleMesh>Expand description
Compute the boolean intersection of two closed triangle meshes.
Returns a mesh containing only the regions inside both a and b.
A.intersection(B)
+-------+
| |
| A |
| +--+----+ = +--+
+----+--+ | +--+
| B |
| |
+-------+